"use strict";
/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.BroadcasterLambdaFactory = void 0;
const events_1 = require("events");
const lambda_1 = require("./lambda");
class BroadcasterLambdaFactory extends events_1.EventEmitter {
    constructor(publisher, serviceConfiguration, clientManager) {
        super();
        this.publisher = publisher;
        this.serviceConfiguration = serviceConfiguration;
        this.clientManager = clientManager;
        this.publisher.on("error", (error) => {
            // After an IO error we need to recreate the lambda
            this.emit("error", error);
        });
    }
    async create(config, context) {
        return new lambda_1.BroadcasterLambda(this.publisher, context, this.serviceConfiguration, this.clientManager);
    }
    async dispose() {
        await this.publisher.close();
    }
}
exports.BroadcasterLambdaFactory = BroadcasterLambdaFactory;
//# sourceMappingURL=lambdaFactory.js.map